@@ -64,7 +64,7 @@ ardeco_get_dataset_data <- function(variable,
   nutsLevel <- nutsLevel$nutsLevel
 
   #	define the URl base of REST API
-  url <- "https://urban.jrc.ec.europa.eu/ardeco-api-v2/rest/export/"
+  url <- "https://territorial.ec.europa.eu/ardeco-api-v2/rest/export/"
 
   # 1) check validity of input parameters
   # 	1.1) variable parameter
