@@ -54,7 +54,7 @@ ardeco_get_tercet_list <- function(var_code) {
           "query": "{territorialTercetList (territorialLevelId: 3) {id name territorialTercetClassList {id name}}}"
           }'
     # URL endpoint GraphQL
-    url <- 'https://urban.jrc.ec.europa.eu/api/graphql'
+    url <- 'https://territorial.ec.europa.eu/api/graphql'
     response <- POST(url,
                      add_headers(.headers = c("Content-Type" = "application/json")),
                      body = query,
