@@ -18,7 +18,7 @@ ardeco_get_variable_props <- function(variable) {
   code <- NULL
 
   # root of the URL to access to graphQL API for ARDECO
-  link <- 'https://urban.jrc.ec.europa.eu/ardeco-api-v2/graphql'
+  link <- 'https://territorial.ec.europa.eu/ardeco-api-v2/graphql'
   conn <- GraphqlClient$new(url=link)
 
   # build the graphql query to recover the list of variables
